@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Supporter;
-$BalanceOfPower::Role::Supporter::VERSION = '0.400110';
+$BalanceOfPower::Role::Supporter::VERSION = '0.400115';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -157,6 +157,14 @@ sub military_support_garbage_collector
 sub rebel_military_support_garbage_collector
 {
     my $self = shift;
+    for($self->rebel_military_supports->all)
+    {
+        say $_->node1 . " => " . $_->node2;
+        if(! $self->at_civil_war($_->node2))
+        {
+            $self->stop_rebel_military_support($self->get_nation($_->node1), $self->get_nation($_->node2));
+        }
+    }
     $self->rebel_military_supports->garbage_collector(sub { my $rel = shift; return $rel->army <= 0 });
 }
 
